==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/summary/state/component-cluster-status/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ConnectionStatus, PortStatus, ProcessGroupStatus, ProcessorStatus, RemoteProcessGroupStatus } from '../index';
import { ComponentType } from 'libs/shared/src';

export const componentClusterStatusFeatureKey = 'component-cluster-status';

export interface ComponentClusterStatusRequest {
    id: string;
    componentType: ComponentType;
}

export interface ComponentClusterStatusResponse {
    clusterStatusEntity: ClusterStatusEntity;
    componentType: ComponentType;
}

export interface ClusterStatusEntity {
    canRead: boolean;
    processorStatus?: ProcessorStatus;
    portStatus?: PortStatus;
    processGroupStatus?: ProcessGroupStatus;
    remoteProcessGroupStatus?: RemoteProcessGroupStatus;
    connectionStatus?: ConnectionStatus;
}

export interface ComponentClusterStatusState {
    clusterStatus: ClusterStatusEntity | null;
    latestRequest: ComponentClusterStatusRequest | null;
    loadedTimestamp: string;
    status: 'pending' | 'loading' | 'success';
}

==> nifi-2.7.2-source-release.zip: nifi-2.7.2/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/summary/state/component-cluster-status/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ConnectionStatus, PortStatus, ProcessGroupStatus, ProcessorStatus, RemoteProcessGroupStatus } from '../index';
import { ComponentType } from '@nifi/shared';

export const componentClusterStatusFeatureKey = 'component-cluster-status';

export interface ComponentClusterStatusRequest {
    id: string;
    componentType: ComponentType;
}

export interface ComponentClusterStatusResponse {
    clusterStatusEntity: ClusterStatusEntity;
    componentType: ComponentType;
}

export interface ClusterStatusEntity {
    canRead: boolean;
    processorStatus?: ProcessorStatus;
    portStatus?: PortStatus;
    processGroupStatus?: ProcessGroupStatus;
    remoteProcessGroupStatus?: RemoteProcessGroupStatus;
    connectionStatus?: ConnectionStatus;
}

export interface ComponentClusterStatusState {
    clusterStatus: ClusterStatusEntity | null;
    latestRequest: ComponentClusterStatusRequest | null;
    loadedTimestamp: string;
    status: 'pending' | 'loading' | 'success';
}
